/*
 *  soapUI, copyright (C) 2004-2007 eviware.com 
 *
 *  soapUI is free software; you can redistribute it and/or modify it under the 
 *  terms of version 2.1 of the GNU Lesser General Public License as published by 
 *  the Free Software Foundation.
 *
 *  soapUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 *  even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 *  See the GNU Lesser General Public License for more details at gnu.org.
 */

package com.eviware.soapui.impl.wsdl.submit.filters;

import java.io.StringWriter;

import org.w3c.dom.Document;

import com.eviware.soapui.impl.wsdl.WsdlRequest;
import com.eviware.soapui.impl.wsdl.endpoint.DefaultEndpointStrategy;
import com.eviware.soapui.impl.wsdl.endpoint.DefaultEndpointStrategy.EndpointDefaults;
import com.eviware.soapui.impl.wsdl.submit.RequestFilter;
import com.eviware.soapui.impl.wsdl.submit.transports.http.BaseHttpRequestTransport;
import com.eviware.soapui.impl.wsdl.support.wss.OutgoingWss;
import com.eviware.soapui.impl.wsdl.support.wss.WssContainer;
import com.eviware.soapui.model.iface.SubmitContext;
import com.eviware.soapui.support.StringUtils;
import com.eviware.soapui.support.xml.XmlUtils;

public class WssRequestFilter extends AbstractWssRequestFilter implements RequestFilter
{
	public void filterRequest( SubmitContext context, WsdlRequest wsdlRequest )
	{
		WssContainer wssContainer = wsdlRequest.getOperation().getInterface().getProject().getWssContainer();
		OutgoingWss outgoingWss = wssContainer.getOutgoingByName( wsdlRequest.getOutgoingWss() );
		
		DefaultEndpointStrategy des = ( DefaultEndpointStrategy ) wsdlRequest.getOperation().getInterface().getProject().getEndpointStrategy();
		EndpointDefaults endpointDefaults = des.getEndpointDefaults( context.expand( wsdlRequest.getEndpoint() ) );
		if( StringUtils.hasContent( endpointDefaults.getOutgoingWss() ))
			outgoingWss = wssContainer.getOutgoingByName( endpointDefaults.getOutgoingWss() );
		
		if( outgoingWss == null )
			return;
		
		try
		{
			Document wssDocument = getWssDocument( context );
			outgoingWss.processOutgoing( wssDocument, context );
			StringWriter writer = new StringWriter();
			XmlUtils.serialize( wssDocument, writer );
			context.setProperty( BaseHttpRequestTransport.REQUEST_CONTENT, writer.toString() );
		}
		catch( Exception e )
		{
			e.printStackTrace();
		}
	}
}
